# Documentation string. I wonder what ever refers to it? 

__doc__ = """ZRTChat item.  Holds information about a particular chat submission"""

# Version string. Usually updated automatically by CVS. 

__version__ = '0.3' 

from Globals import HTMLFile      # fakes a method from a DTML file
from Globals import MessageDialog # provides the "your changes have been saved" dialog
from Globals import Persistent    # makes an object stick in the ZODB
from OFS.CopySupport import CopySource

import OFS.SimpleItem
import Acquisition
import AccessControl.Role
import DateTime


"""No GUI constructors here; these are only added programmatically"""
def manage_addChatItem(self, REQUEST):
    """Add a Chat Item to a ZRTChat."""
    dt = DateTime.DateTime()
    id = '%s_%s' % (dt.strftime('%Y%m%d%H%M%S%s'),REQUEST.zrtcuser)
    self._setObject(id, ChatItem(id, dt, REQUEST))


"""the class for ChatItems"""

class ChatItem(
    OFS.SimpleItem.Item,   # A simple Principia object. Not Folderish. 
    Persistent,            # Make us persistent
    Acquisition.Implicit,  # Probably doesn't need this?
    AccessControl.Role.RoleManager, # Security manager. 
    CopySource
    ): 
    """the chatitem class"""

    meta_type = 'ChatItem' # what do people think they're adding? 
    
    icon='misc_/ZRTChat/ChatItem'
    
    _canCopy=1 #we can be copied

    manage_options = ( # what management options are there?
	{'label': 'Info',       'action': 'manage_main'},) 

    __ac_permissions__=( # what permissions make sense for us? 
	('View management screens', ('manage_tabs','manage_main')),
	('Change permissions',      ('manage_access',)           ),
	('Change ChatItems'     ,     ('manage_edit',)             ),
	('View ChatItems',            ('',)                        ),
	)

    def __init__(self, id, dt, REQUEST): 
        """initialise a new instance of ChatItem"""
        self.id = id
        self.dt = dt
        self.zrtcuser=REQUEST.zrtcuser
        self.zrtcmessage=REQUEST.zrtcmessage


    def title(self):
        """return up to 40 chars of the message when asked for title"""
        if len(self.zrtcmessage) > 40:
            return '%s ...' % self.zrtcmessage[:40]
        else:
            return self.zrtcmessage
        
    def tablerow(self):
        """make a tablerow from the item info"""
        return "<tr><td>%s</td><td>%s</td><td>%s></td></tr>" % (self.id, self.zrtcmessage, self.dt)
            
    
    manage_main = HTMLFile('ChatItemEdit', globals()) # Management Interface
    
    def manage_edit(self, REQUEST=None): 
        """re-edit a zrtchatitem; shouldn't happen much, 
        but that's why dt is part of this rather
        than just using its modification date."""
        self.zrtcmessage=REQUEST.zrtcmessage

        if REQUEST is not None:
	        return MessageDialog(
		    title = 'Edited',
		    message = "Message for %s changed." % self.id,
		    action = './manage_main',
		    )
